@@ -79,7 +79,8 @@ def parse_args(action, usage):
 
     args.playlists = utils.conform(args.playlists)
 
-    play_actions.parse_args_sort(args, action)
+    args.action = action
+    play_actions.parse_args_sort(args)
 
     log.info(utils.dict_filter_bool(args.__dict__))
 
@@ -109,34 +110,32 @@ def construct_query(args) -> Tuple[str, dict]:
     )
 
     if "uploader" in m_columns:
-        cf.append(
-            f"and media.uploader not in (select uploader from playlists where category='{consts.BLOCK_THE_CHANNEL}')"
-        )
+        cf.append(f"and m.uploader not in (select uploader from playlists where category='{consts.BLOCK_THE_CHANNEL}')")
 
     args.sql_filter = " ".join(cf)
     args.sql_filter_bindings = bindings
 
     LIMIT = "LIMIT " + str(args.limit) if args.limit else ""
     query = f"""select
-            media.path
+            m.path
             {', playlist_path' if 'playlist_path' in m_columns else ''}
-            , media.title
-            {', media.duration' if 'duration' in m_columns else ''}
-            , media.time_created
-            {', media.size' if 'size' in m_columns else ''}
-            {', media.ie_key' if 'ie_key' in m_columns else ''}
-            {', media.time_modified' if 'time_modified' in m_columns else ''}
-            {', media.time_downloaded' if 'time_downloaded' in m_columns else ''}
-            {', media.time_deleted' if 'time_deleted' in m_columns else ''}
-            {', media.error' if 'error' in m_columns else ''}
-            {', media.id' if 'id' in m_columns else ''}
+            , m.title
+            {', m.duration' if 'duration' in m_columns else ''}
+            , m.time_created
+            {', m.size' if 'size' in m_columns else ''}
+            {', m.ie_key' if 'ie_key' in m_columns else ''}
+            {', m.time_modified' if 'time_modified' in m_columns else ''}
+            {', m.time_downloaded' if 'time_downloaded' in m_columns else ''}
+            {', m.time_deleted' if 'time_deleted' in m_columns else ''}
+            {', m.error' if 'error' in m_columns else ''}
+            {', m.id' if 'id' in m_columns else ''}
             {', p.dl_config' if 'dl_config' in pl_columns else ''}
             , coalesce(p.category, p.ie_key) category
-        FROM media
-        LEFT JOIN playlists p on (p.path = media.playlist_path {"and p.ie_key != 'Local' and p.ie_key = media.ie_key" if 'ie_key' in m_columns else ''})
+        FROM media m
+        LEFT JOIN playlists p on (p.path = m.playlist_path {"and p.ie_key != 'Local' and p.ie_key = m.ie_key" if 'ie_key' in m_columns else ''})
         WHERE 1=1
-            and media.time_downloaded=0
-            and media.time_deleted=0
+            and (m.time_downloaded is null or m.time_downloaded=0)
+            and (m.time_deleted is null or m.time_deleted=0)
             and (p.time_deleted is null or p.time_deleted=0)
             {'AND (score IS NULL OR score > 7)' if 'score' in m_columns else ''}
             {'AND (upvote_ratio IS NULL OR upvote_ratio > 0.73)' if 'upvote_ratio' in m_columns else ''}
@@ -223,14 +222,20 @@ def dl_download(args=None) -> None:
             log.info("[%s]: Skipping unsupported URL (safe_mode)", m["path"])
             continue
 
-        # check again in case it was already completed by another process
-        path = list(
+        # check again in case it was already attempted by another process
+        previous_time_attempted = m.get("time_modified") or 0
+        download_already_attempted = list(
             args.db.query(
-                f"select path from media where (path=? or {'web' if 'webpath' in m_columns else ''}path=?) {'AND time_modified = ' + str(m.get('time_modified') or 0) if 'time_modified' in m_columns else ''}",
+                f"""
+                SELECT path from media
+                WHERE 1=1
+                AND (path=? or {'web' if 'webpath' in m_columns else ''}path=?)
+                {f'AND time_modified > {str(previous_time_attempted)}' if 'time_modified' in m_columns else ''}
+                """,
                 [m["path"], m["path"]],
             )
         )
-        if not path:
+        if download_already_attempted:
             log.info("[%s]: Already downloaded. Skipping!", m["path"])
             continue
 
