@@ -50,7 +50,7 @@ def parse_args(action, usage) -> argparse.Namespace:
     parser.add_argument("--verbose", "-v", action="count", default=0)
     parser.add_argument("--db", "-db", help=argparse.SUPPRESS)
 
-    parser.add_argument("database", nargs="?")
+    parser.add_argument("database")
     if action == SC.fsadd:
         parser.add_argument("paths", nargs="+")
     args = parser.parse_args()
@@ -149,17 +149,11 @@ def extract_metadata(mp_args, f) -> Optional[Dict[str, int]]:
     return media
 
 
-def extract_chunk(args, chunk_paths) -> None:
-    from joblib import Parallel, delayed
-
-    n_jobs = -1
-    if args.io_multiplier > 1:
-        n_jobs = int(consts.CPU_COUNT * args.io_multiplier)  # useful for text, image, filesystem db types
-    if args.verbose >= 2:
-        n_jobs = 1
+def extract_chunk(args, parallel, chunk_paths) -> None:
+    from joblib import delayed
 
     mp_args = argparse.Namespace(**{k: v for k, v in args.__dict__.items() if k not in {"db"}})
-    metadata = Parallel(n_jobs=n_jobs)(delayed(extract_metadata)(mp_args, p) for p in chunk_paths) or []
+    metadata = parallel((delayed(extract_metadata)(mp_args, p) for p in chunk_paths) or [])
 
     if args.profile == DBType.image:
         metadata = books.extract_image_metadata_chunk(metadata, chunk_paths)
@@ -234,8 +228,17 @@ def _add_folder(args, folder_path: Path) -> None:
 
 
 def scan_path(args, path_str: str) -> int:
-    path = Path(path_str).resolve()
+    from joblib import Parallel
 
+    n_jobs = -1
+    if args.io_multiplier > 1:
+        n_jobs = int(consts.CPU_COUNT * args.io_multiplier)  # useful for text, image, filesystem db types
+    if args.verbose >= 2:
+        n_jobs = 1
+
+    threadsafe = [DBType.audio, DBType.video, DBType.filesystem]  # TODO: check text / image
+
+    path = Path(path_str).resolve()
     if not path.exists():
         print(f"[{path}] Path does not exist")
         if args.force:
@@ -256,10 +259,11 @@ def scan_path(args, path_str: str) -> int:
             batch_count = consts.SQLITE_PARAM_LIMIT // 100
         chunks_count = math.ceil(len(new_files) / batch_count)
         df_chunked = utils.chunks(new_files, batch_count)
-        for idx, l in enumerate(df_chunked):
-            percent = ((batch_count * idx) + len(l)) / len(new_files) * 100
-            print(f"[{path}] Extracting metadata {percent:3.1f}% (chunk {idx + 1} of {chunks_count})")
-            extract_chunk(args, l)
+        with Parallel(n_jobs, prefer="threads" if args.profile in threadsafe else None) as parallel:
+            for idx, l in enumerate(df_chunked):
+                percent = ((batch_count * idx) + len(l)) / len(new_files) * 100
+                print(f"[{path}] Extracting metadata {percent:3.1f}% (chunk {idx + 1} of {chunks_count})")
+                extract_chunk(args, parallel, l)
 
     _add_folder(args, path)
 
@@ -271,39 +275,39 @@ def extractor(args, paths) -> None:
     for path in paths:
         new_files += scan_path(args, path)
 
-    if not args.db["media"].detect_fts() or new_files > 100000:
-        db.optimize(args)
+    log.info("Imported %s paths", new_files)
+
+    if args.profile in [DBType.audio, DBType.video, DBType.text]:
+        if not args.db["media"].detect_fts() or new_files > 100000:
+            db.optimize(args)
 
 
 def fs_add(args=None) -> None:
     if args:
-        sys.argv[1:] = args
+        sys.argv = ["lb"] + args
 
     args = parse_args(
         SC.fsadd,
         """library fsadd [--audio | --video | --image |  --text | --filesystem] -c CATEGORY [database] paths ...
 
     The default database type is video:
-        library fsadd ./tv/
-        library fsadd --video ./tv/  # equivalent
+        library fsadd tv.db ./tv/
+        library fsadd --video tv.db ./tv/  # equivalent
 
-    This will create audio.db in the current directory:
-        library fsadd --audio ./music/
+    You can also create audio databases. Both audio and video use ffmpeg to read metadata:
+        library fsadd --audio audio.db ./music/
 
-    This will create image.db in the current directory:
-        library fsadd --image ./photos/
+    Image uses ExifTool:
+        library fsadd --image image.db ./photos/
 
-    This will create text.db in the current directory:
-        library fsadd --text ./documents_and_books/
+    Text will try to read files and save the contents into a searchable database:
+        library fsadd --text text.db ./documents_and_books/
 
-    Create text database and scan with OCR and speech-recognition:
-        library fsadd --text --ocr --speech-recognition ./receipts_and_messages/
+    Create a text database and scan with OCR and speech-recognition:
+        library fsadd --text --ocr --speech-recognition ocr.db ./receipts_and_messages/
 
-    Create video database and read internal/external subtitle files for use in search:
-        library fsadd --scan-subtitles ./tv/
-
-    The database location must be specified to reference more than one path:
-        library fsadd --audio podcasts.db ./podcasts/ ./another/folder/
+    Create a video database and read internal/external subtitle files into a searchable database:
+        library fsadd --scan-subtitles tv.search.db ./tv/ ./movies/
 
     Remove path roots with --force
         library fsadd audio.db /mnt/d/Youtube/
@@ -321,7 +325,7 @@ def fs_add(args=None) -> None:
 
 def fs_update(args=None) -> None:
     if args:
-        sys.argv[1:] = args
+        sys.argv = ["lb"] + args
 
     args = parse_args(
         SC.fsupdate,
